====================
Astrophysics toolset
====================


.. image:: https://img.shields.io/pypi/v/astrophysics_toolset.svg
        :target: https://pypi.python.org/pypi/astrophysics_toolset

.. image:: https://img.shields.io/travis/cphyc/astrophysics_toolset.svg
        :target: https://travis-ci.com/cphyc/astrophysics_toolset

.. image:: https://readthedocs.org/projects/astrophysics-toolset/badge/?version=latest
        :target: https://astrophysics-toolset.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/cphyc/astrophysics_toolset/shield.svg
     :target: https://pyup.io/repos/github/cphyc/astrophysics_toolset/
     :alt: Updates



Python package with some astrophysics-related stuff


* Free software: MIT license
* Documentation: https://astrophysics-toolset.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
